Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(323)

Unified Diff: remoting/client/jni/jni_frame_consumer.h

Issue 2007123003: [Android Client] Break down multi-threaded classes by thread (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rename JniSecretFetcher to JniPairingSecretFetcher Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/client/jni/jni_display_handler.cc ('k') | remoting/client/jni/jni_frame_consumer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/client/jni/jni_frame_consumer.h
diff --git a/remoting/client/jni/jni_frame_consumer.h b/remoting/client/jni/jni_frame_consumer.h
index b4c0d7f29117e753a52ca53df5b4095018fbc9ac..a6607a0aa4fa7be44b0bf9a08b35a84c16fd9a51 100644
--- a/remoting/client/jni/jni_frame_consumer.h
+++ b/remoting/client/jni/jni_frame_consumer.h
@@ -17,13 +17,15 @@
namespace remoting {
class ChromotingJniRuntime;
+class JniDisplayHandler;
class JniClient;
// FrameConsumer implementation that draws onto a JNI direct byte buffer.
class JniFrameConsumer : public protocol::FrameConsumer {
public:
- // Does not take ownership of |jni_runtime|.
- JniFrameConsumer(ChromotingJniRuntime* jni_runtime, JniClient* client);
+ // Does not take ownership of |jni_runtime| or |display|.
+ JniFrameConsumer(ChromotingJniRuntime* jni_runtime,
+ base::WeakPtr<JniDisplayHandler> display);
~JniFrameConsumer() override;
« no previous file with comments | « remoting/client/jni/jni_display_handler.cc ('k') | remoting/client/jni/jni_frame_consumer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698